runtimev1

package
v1.4.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 7, 2026 License: MPL-2.0 Imports: 11 Imported by: 0

Documentation

Overview

Package runtimev1 provides Runtime Protocol v1 messages, RPC bindings, and compatibility validation.

Index

Constants

const (
	RuntimeDriver_Info_FullMethodName                  = "/devsy.runtime.v1.RuntimeDriver/Info"
	RuntimeDriver_Preflight_FullMethodName             = "/devsy.runtime.v1.RuntimeDriver/Preflight"
	RuntimeDriver_ProvisioningPreflight_FullMethodName = "/devsy.runtime.v1.RuntimeDriver/ProvisioningPreflight"
	RuntimeDriver_Find_FullMethodName                  = "/devsy.runtime.v1.RuntimeDriver/Find"
	RuntimeDriver_TargetArchitecture_FullMethodName    = "/devsy.runtime.v1.RuntimeDriver/TargetArchitecture"
	RuntimeDriver_RunImage_FullMethodName              = "/devsy.runtime.v1.RuntimeDriver/RunImage"
	RuntimeDriver_Start_FullMethodName                 = "/devsy.runtime.v1.RuntimeDriver/Start"
	RuntimeDriver_Stop_FullMethodName                  = "/devsy.runtime.v1.RuntimeDriver/Stop"
	RuntimeDriver_Delete_FullMethodName                = "/devsy.runtime.v1.RuntimeDriver/Delete"
	RuntimeDriver_Exec_FullMethodName                  = "/devsy.runtime.v1.RuntimeDriver/Exec"
	RuntimeDriver_Logs_FullMethodName                  = "/devsy.runtime.v1.RuntimeDriver/Logs"
)
const (
	// APIMajor changes when the runtime wire contract breaks compatibility.
	APIMajor uint32 = 1
	// APIMinor tracks compatible additions within the current major generation.
	APIMinor uint32 = 1
	// ChunkSize is the recommended maximum payload for each Exec data frame.
	ChunkSize = 32 * 1024
)

Variables

var (
	MountType_name = map[int32]string{
		0: "MOUNT_TYPE_UNSPECIFIED",
		1: "MOUNT_TYPE_BIND",
		2: "MOUNT_TYPE_VOLUME",
		3: "MOUNT_TYPE_TMPFS",
	}
	MountType_value = map[string]int32{
		"MOUNT_TYPE_UNSPECIFIED": 0,
		"MOUNT_TYPE_BIND":        1,
		"MOUNT_TYPE_VOLUME":      2,
		"MOUNT_TYPE_TMPFS":       3,
	}
)

Enum value maps for MountType.

var (
	RecreateMode_name = map[int32]string{
		0: "RECREATE_MODE_UNSPECIFIED",
		1: "RECREATE_MODE_DELETE",
		2: "RECREATE_MODE_STOP",
	}
	RecreateMode_value = map[string]int32{
		"RECREATE_MODE_UNSPECIFIED": 0,
		"RECREATE_MODE_DELETE":      1,
		"RECREATE_MODE_STOP":        2,
	}
)

Enum value maps for RecreateMode.

var (
	GpuRequirementValue_name = map[int32]string{
		0: "GPU_UNSPECIFIED",
		1: "GPU_FALSE",
		2: "GPU_OPTIONAL",
		3: "GPU_REQUIRED",
	}
	GpuRequirementValue_value = map[string]int32{
		"GPU_UNSPECIFIED": 0,
		"GPU_FALSE":       1,
		"GPU_OPTIONAL":    2,
		"GPU_REQUIRED":    3,
	}
)

Enum value maps for GpuRequirementValue.

var (
	RuntimeErrorCode_name = map[int32]string{
		0:  "RUNTIME_ERROR_CODE_UNKNOWN",
		1:  "RUNTIME_ERROR_CODE_NOT_FOUND",
		2:  "RUNTIME_ERROR_CODE_ALREADY_EXISTS",
		3:  "RUNTIME_ERROR_CODE_INVALID_ARGUMENT",
		4:  "RUNTIME_ERROR_CODE_UNSUPPORTED",
		5:  "RUNTIME_ERROR_CODE_UNAVAILABLE",
		6:  "RUNTIME_ERROR_CODE_FAILED_PRECONDITION",
		7:  "RUNTIME_ERROR_CODE_PERMISSION_DENIED",
		8:  "RUNTIME_ERROR_CODE_TIMEOUT",
		9:  "RUNTIME_ERROR_CODE_CANCELLED",
		10: "RUNTIME_ERROR_CODE_RUNTIME_FAILURE",
		11: "RUNTIME_ERROR_CODE_INCOMPATIBLE_VERSION",
	}
	RuntimeErrorCode_value = map[string]int32{
		"RUNTIME_ERROR_CODE_UNKNOWN":              0,
		"RUNTIME_ERROR_CODE_NOT_FOUND":            1,
		"RUNTIME_ERROR_CODE_ALREADY_EXISTS":       2,
		"RUNTIME_ERROR_CODE_INVALID_ARGUMENT":     3,
		"RUNTIME_ERROR_CODE_UNSUPPORTED":          4,
		"RUNTIME_ERROR_CODE_UNAVAILABLE":          5,
		"RUNTIME_ERROR_CODE_FAILED_PRECONDITION":  6,
		"RUNTIME_ERROR_CODE_PERMISSION_DENIED":    7,
		"RUNTIME_ERROR_CODE_TIMEOUT":              8,
		"RUNTIME_ERROR_CODE_CANCELLED":            9,
		"RUNTIME_ERROR_CODE_RUNTIME_FAILURE":      10,
		"RUNTIME_ERROR_CODE_INCOMPATIBLE_VERSION": 11,
	}
)

Enum value maps for RuntimeErrorCode.

var File_devsy_runtime_v1_runtime_proto protoreflect.FileDescriptor
var RuntimeDriver_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "devsy.runtime.v1.RuntimeDriver",
	HandlerType: (*RuntimeDriverServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "Info",
			Handler:    _RuntimeDriver_Info_Handler,
		},
		{
			MethodName: "Preflight",
			Handler:    _RuntimeDriver_Preflight_Handler,
		},
		{
			MethodName: "ProvisioningPreflight",
			Handler:    _RuntimeDriver_ProvisioningPreflight_Handler,
		},
		{
			MethodName: "Find",
			Handler:    _RuntimeDriver_Find_Handler,
		},
		{
			MethodName: "TargetArchitecture",
			Handler:    _RuntimeDriver_TargetArchitecture_Handler,
		},
		{
			MethodName: "RunImage",
			Handler:    _RuntimeDriver_RunImage_Handler,
		},
		{
			MethodName: "Start",
			Handler:    _RuntimeDriver_Start_Handler,
		},
		{
			MethodName: "Stop",
			Handler:    _RuntimeDriver_Stop_Handler,
		},
		{
			MethodName: "Delete",
			Handler:    _RuntimeDriver_Delete_Handler,
		},
	},
	Streams: []grpc.StreamDesc{
		{
			StreamName:    "Exec",
			Handler:       _RuntimeDriver_Exec_Handler,
			ServerStreams: true,
			ClientStreams: true,
		},
		{
			StreamName:    "Logs",
			Handler:       _RuntimeDriver_Logs_Handler,
			ServerStreams: true,
		},
	},
	Metadata: "devsy/runtime/v1/runtime.proto",
}

RuntimeDriver_ServiceDesc is the grpc.ServiceDesc for RuntimeDriver service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterRuntimeDriverServer

func RegisterRuntimeDriverServer(s grpc.ServiceRegistrar, srv RuntimeDriverServer)

func ValidateInfo

func ValidateInfo(info *InfoResponse) error

ValidateInfo checks the behavior the host needs before invoking a runtime. Same-major newer minor versions are compatible; unknown behavioral enum values are rejected rather than silently selecting an unsafe policy.

Types

type Capabilities

type Capabilities struct {
	MountTypes             []MountType  `` /* 131-byte string literal not displayed */
	RequiresMountStreaming bool         `` /* 130-byte string literal not displayed */
	RequiresWorkspaceChown bool         `` /* 130-byte string literal not displayed */
	RecreateMode           RecreateMode `` /* 133-byte string literal not displayed */
	ProvisioningPreflight  bool         `protobuf:"varint,5,opt,name=provisioning_preflight,json=provisioningPreflight,proto3" json:"provisioning_preflight,omitempty"`
	Reprovision            bool         `protobuf:"varint,6,opt,name=reprovision,proto3" json:"reprovision,omitempty"`
	Logs                   bool         `protobuf:"varint,7,opt,name=logs,proto3" json:"logs,omitempty"`
	// contains filtered or unexported fields
}

func (*Capabilities) Descriptor deprecated

func (*Capabilities) Descriptor() ([]byte, []int)

Deprecated: Use Capabilities.ProtoReflect.Descriptor instead.

func (*Capabilities) GetLogs

func (x *Capabilities) GetLogs() bool

func (*Capabilities) GetMountTypes

func (x *Capabilities) GetMountTypes() []MountType

func (*Capabilities) GetProvisioningPreflight

func (x *Capabilities) GetProvisioningPreflight() bool

func (*Capabilities) GetRecreateMode

func (x *Capabilities) GetRecreateMode() RecreateMode

func (*Capabilities) GetReprovision

func (x *Capabilities) GetReprovision() bool

func (*Capabilities) GetRequiresMountStreaming

func (x *Capabilities) GetRequiresMountStreaming() bool

func (*Capabilities) GetRequiresWorkspaceChown

func (x *Capabilities) GetRequiresWorkspaceChown() bool

func (*Capabilities) ProtoMessage

func (*Capabilities) ProtoMessage()

func (*Capabilities) ProtoReflect

func (x *Capabilities) ProtoReflect() protoreflect.Message

func (*Capabilities) Reset

func (x *Capabilities) Reset()

func (*Capabilities) String

func (x *Capabilities) String() string

type CloseStdin

type CloseStdin struct {
	// contains filtered or unexported fields
}

func (*CloseStdin) Descriptor deprecated

func (*CloseStdin) Descriptor() ([]byte, []int)

Deprecated: Use CloseStdin.ProtoReflect.Descriptor instead.

func (*CloseStdin) ProtoMessage

func (*CloseStdin) ProtoMessage()

func (*CloseStdin) ProtoReflect

func (x *CloseStdin) ProtoReflect() protoreflect.Message

func (*CloseStdin) Reset

func (x *CloseStdin) Reset()

func (*CloseStdin) String

func (x *CloseStdin) String() string

type ContainerConfig

type ContainerConfig struct {
	Labels     map[string]string `` /* 139-byte string literal not displayed */
	WorkingDir string            `protobuf:"bytes,2,opt,name=working_dir,json=workingDir,proto3" json:"working_dir,omitempty"`
	User       string            `protobuf:"bytes,3,opt,name=user,proto3" json:"user,omitempty"`
	// contains filtered or unexported fields
}

func (*ContainerConfig) Descriptor deprecated

func (*ContainerConfig) Descriptor() ([]byte, []int)

Deprecated: Use ContainerConfig.ProtoReflect.Descriptor instead.

func (*ContainerConfig) GetLabels

func (x *ContainerConfig) GetLabels() map[string]string

func (*ContainerConfig) GetUser

func (x *ContainerConfig) GetUser() string

func (*ContainerConfig) GetWorkingDir

func (x *ContainerConfig) GetWorkingDir() string

func (*ContainerConfig) ProtoMessage

func (*ContainerConfig) ProtoMessage()

func (*ContainerConfig) ProtoReflect

func (x *ContainerConfig) ProtoReflect() protoreflect.Message

func (*ContainerConfig) Reset

func (x *ContainerConfig) Reset()

func (*ContainerConfig) String

func (x *ContainerConfig) String() string

type ContainerDetails

type ContainerDetails struct {
	Id        string            `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	CreatedAt string            `protobuf:"bytes,2,opt,name=created_at,json=createdAt,proto3" json:"created_at,omitempty"`
	State     *ContainerState   `protobuf:"bytes,3,opt,name=state,proto3" json:"state,omitempty"`
	Config    *ContainerConfig  `protobuf:"bytes,4,opt,name=config,proto3" json:"config,omitempty"`
	Mounts    []*ContainerMount `protobuf:"bytes,5,rep,name=mounts,proto3" json:"mounts,omitempty"`
	// contains filtered or unexported fields
}

func (*ContainerDetails) Descriptor deprecated

func (*ContainerDetails) Descriptor() ([]byte, []int)

Deprecated: Use ContainerDetails.ProtoReflect.Descriptor instead.

func (*ContainerDetails) GetConfig

func (x *ContainerDetails) GetConfig() *ContainerConfig

func (*ContainerDetails) GetCreatedAt

func (x *ContainerDetails) GetCreatedAt() string

func (*ContainerDetails) GetId

func (x *ContainerDetails) GetId() string

func (*ContainerDetails) GetMounts

func (x *ContainerDetails) GetMounts() []*ContainerMount

func (*ContainerDetails) GetState

func (x *ContainerDetails) GetState() *ContainerState

func (*ContainerDetails) ProtoMessage

func (*ContainerDetails) ProtoMessage()

func (*ContainerDetails) ProtoReflect

func (x *ContainerDetails) ProtoReflect() protoreflect.Message

func (*ContainerDetails) Reset

func (x *ContainerDetails) Reset()

func (*ContainerDetails) String

func (x *ContainerDetails) String() string

type ContainerMount

type ContainerMount struct {
	Type        string `protobuf:"bytes,1,opt,name=type,proto3" json:"type,omitempty"`
	Source      string `protobuf:"bytes,2,opt,name=source,proto3" json:"source,omitempty"`
	Destination string `protobuf:"bytes,3,opt,name=destination,proto3" json:"destination,omitempty"`
	// contains filtered or unexported fields
}

func (*ContainerMount) Descriptor deprecated

func (*ContainerMount) Descriptor() ([]byte, []int)

Deprecated: Use ContainerMount.ProtoReflect.Descriptor instead.

func (*ContainerMount) GetDestination

func (x *ContainerMount) GetDestination() string

func (*ContainerMount) GetSource

func (x *ContainerMount) GetSource() string

func (*ContainerMount) GetType

func (x *ContainerMount) GetType() string

func (*ContainerMount) ProtoMessage

func (*ContainerMount) ProtoMessage()

func (*ContainerMount) ProtoReflect

func (x *ContainerMount) ProtoReflect() protoreflect.Message

func (*ContainerMount) Reset

func (x *ContainerMount) Reset()

func (*ContainerMount) String

func (x *ContainerMount) String() string

type ContainerState

type ContainerState struct {
	Status    string `protobuf:"bytes,1,opt,name=status,proto3" json:"status,omitempty"`
	StartedAt string `protobuf:"bytes,2,opt,name=started_at,json=startedAt,proto3" json:"started_at,omitempty"`
	ExitCode  int32  `protobuf:"varint,3,opt,name=exit_code,json=exitCode,proto3" json:"exit_code,omitempty"`
	Error     string `protobuf:"bytes,4,opt,name=error,proto3" json:"error,omitempty"`
	// contains filtered or unexported fields
}

func (*ContainerState) Descriptor deprecated

func (*ContainerState) Descriptor() ([]byte, []int)

Deprecated: Use ContainerState.ProtoReflect.Descriptor instead.

func (*ContainerState) GetError

func (x *ContainerState) GetError() string

func (*ContainerState) GetExitCode

func (x *ContainerState) GetExitCode() int32

func (*ContainerState) GetStartedAt

func (x *ContainerState) GetStartedAt() string

func (*ContainerState) GetStatus

func (x *ContainerState) GetStatus() string

func (*ContainerState) ProtoMessage

func (*ContainerState) ProtoMessage()

func (*ContainerState) ProtoReflect

func (x *ContainerState) ProtoReflect() protoreflect.Message

func (*ContainerState) Reset

func (x *ContainerState) Reset()

func (*ContainerState) String

func (x *ContainerState) String() string

type DeleteRequest

type DeleteRequest struct {
	WorkspaceId string `protobuf:"bytes,1,opt,name=workspace_id,json=workspaceId,proto3" json:"workspace_id,omitempty"`
	// contains filtered or unexported fields
}

func (*DeleteRequest) Descriptor deprecated

func (*DeleteRequest) Descriptor() ([]byte, []int)

Deprecated: Use DeleteRequest.ProtoReflect.Descriptor instead.

func (*DeleteRequest) GetWorkspaceId

func (x *DeleteRequest) GetWorkspaceId() string

func (*DeleteRequest) ProtoMessage

func (*DeleteRequest) ProtoMessage()

func (*DeleteRequest) ProtoReflect

func (x *DeleteRequest) ProtoReflect() protoreflect.Message

func (*DeleteRequest) Reset

func (x *DeleteRequest) Reset()

func (*DeleteRequest) String

func (x *DeleteRequest) String() string

type DeleteResponse

type DeleteResponse struct {
	// contains filtered or unexported fields
}

func (*DeleteResponse) Descriptor deprecated

func (*DeleteResponse) Descriptor() ([]byte, []int)

Deprecated: Use DeleteResponse.ProtoReflect.Descriptor instead.

func (*DeleteResponse) ProtoMessage

func (*DeleteResponse) ProtoMessage()

func (*DeleteResponse) ProtoReflect

func (x *DeleteResponse) ProtoReflect() protoreflect.Message

func (*DeleteResponse) Reset

func (x *DeleteResponse) Reset()

func (*DeleteResponse) String

func (x *DeleteResponse) String() string

type ExecClientMessage

type ExecClientMessage struct {

	// Types that are valid to be assigned to Payload:
	//
	//	*ExecClientMessage_Start
	//	*ExecClientMessage_Stdin
	//	*ExecClientMessage_CloseStdin
	Payload isExecClientMessage_Payload `protobuf_oneof:"payload"`
	// contains filtered or unexported fields
}

func (*ExecClientMessage) Descriptor deprecated

func (*ExecClientMessage) Descriptor() ([]byte, []int)

Deprecated: Use ExecClientMessage.ProtoReflect.Descriptor instead.

func (*ExecClientMessage) GetCloseStdin

func (x *ExecClientMessage) GetCloseStdin() *CloseStdin

func (*ExecClientMessage) GetPayload

func (x *ExecClientMessage) GetPayload() isExecClientMessage_Payload

func (*ExecClientMessage) GetStart

func (x *ExecClientMessage) GetStart() *ExecStart

func (*ExecClientMessage) GetStdin

func (x *ExecClientMessage) GetStdin() []byte

func (*ExecClientMessage) ProtoMessage

func (*ExecClientMessage) ProtoMessage()

func (*ExecClientMessage) ProtoReflect

func (x *ExecClientMessage) ProtoReflect() protoreflect.Message

func (*ExecClientMessage) Reset

func (x *ExecClientMessage) Reset()

func (*ExecClientMessage) String

func (x *ExecClientMessage) String() string

type ExecClientMessage_CloseStdin

type ExecClientMessage_CloseStdin struct {
	CloseStdin *CloseStdin `protobuf:"bytes,3,opt,name=close_stdin,json=closeStdin,proto3,oneof"`
}

type ExecClientMessage_Start

type ExecClientMessage_Start struct {
	Start *ExecStart `protobuf:"bytes,1,opt,name=start,proto3,oneof"`
}

type ExecClientMessage_Stdin

type ExecClientMessage_Stdin struct {
	Stdin []byte `protobuf:"bytes,2,opt,name=stdin,proto3,oneof"`
}

type ExecExit

type ExecExit struct {

	// Command success requires exit_code == 0 AND an empty signal.
	ExitCode int32 `protobuf:"varint,1,opt,name=exit_code,json=exitCode,proto3" json:"exit_code,omitempty"`
	// A nonempty signal means failure regardless of exit_code, whose default is 0.
	Signal string `protobuf:"bytes,2,opt,name=signal,proto3" json:"signal,omitempty"`
	// contains filtered or unexported fields
}

func (*ExecExit) Descriptor deprecated

func (*ExecExit) Descriptor() ([]byte, []int)

Deprecated: Use ExecExit.ProtoReflect.Descriptor instead.

func (*ExecExit) GetExitCode

func (x *ExecExit) GetExitCode() int32

func (*ExecExit) GetSignal

func (x *ExecExit) GetSignal() string

func (*ExecExit) ProtoMessage

func (*ExecExit) ProtoMessage()

func (*ExecExit) ProtoReflect

func (x *ExecExit) ProtoReflect() protoreflect.Message

func (*ExecExit) Reset

func (x *ExecExit) Reset()

func (*ExecExit) String

func (x *ExecExit) String() string

type ExecServerMessage

type ExecServerMessage struct {

	// Types that are valid to be assigned to Payload:
	//
	//	*ExecServerMessage_Stdout
	//	*ExecServerMessage_Stderr
	//	*ExecServerMessage_Exit
	Payload isExecServerMessage_Payload `protobuf_oneof:"payload"`
	// contains filtered or unexported fields
}

func (*ExecServerMessage) Descriptor deprecated

func (*ExecServerMessage) Descriptor() ([]byte, []int)

Deprecated: Use ExecServerMessage.ProtoReflect.Descriptor instead.

func (*ExecServerMessage) GetExit

func (x *ExecServerMessage) GetExit() *ExecExit

func (*ExecServerMessage) GetPayload

func (x *ExecServerMessage) GetPayload() isExecServerMessage_Payload

func (*ExecServerMessage) GetStderr

func (x *ExecServerMessage) GetStderr() *OutputChunk

func (*ExecServerMessage) GetStdout

func (x *ExecServerMessage) GetStdout() *OutputChunk

func (*ExecServerMessage) ProtoMessage

func (*ExecServerMessage) ProtoMessage()

func (*ExecServerMessage) ProtoReflect

func (x *ExecServerMessage) ProtoReflect() protoreflect.Message

func (*ExecServerMessage) Reset

func (x *ExecServerMessage) Reset()

func (*ExecServerMessage) String

func (x *ExecServerMessage) String() string

type ExecServerMessage_Exit

type ExecServerMessage_Exit struct {
	Exit *ExecExit `protobuf:"bytes,3,opt,name=exit,proto3,oneof"`
}

type ExecServerMessage_Stderr

type ExecServerMessage_Stderr struct {
	Stderr *OutputChunk `protobuf:"bytes,2,opt,name=stderr,proto3,oneof"`
}

type ExecServerMessage_Stdout

type ExecServerMessage_Stdout struct {
	Stdout *OutputChunk `protobuf:"bytes,1,opt,name=stdout,proto3,oneof"`
}

type ExecStart

type ExecStart struct {
	WorkspaceId string            `protobuf:"bytes,1,opt,name=workspace_id,json=workspaceId,proto3" json:"workspace_id,omitempty"`
	Argv        []string          `protobuf:"bytes,2,rep,name=argv,proto3" json:"argv,omitempty"`
	User        string            `protobuf:"bytes,3,opt,name=user,proto3" json:"user,omitempty"`
	Workdir     string            `protobuf:"bytes,4,opt,name=workdir,proto3" json:"workdir,omitempty"`
	Environment map[string]string `` /* 149-byte string literal not displayed */
	Tty         bool              `protobuf:"varint,6,opt,name=tty,proto3" json:"tty,omitempty"`
	// contains filtered or unexported fields
}

func (*ExecStart) Descriptor deprecated

func (*ExecStart) Descriptor() ([]byte, []int)

Deprecated: Use ExecStart.ProtoReflect.Descriptor instead.

func (*ExecStart) GetArgv

func (x *ExecStart) GetArgv() []string

func (*ExecStart) GetEnvironment

func (x *ExecStart) GetEnvironment() map[string]string

func (*ExecStart) GetTty

func (x *ExecStart) GetTty() bool

func (*ExecStart) GetUser

func (x *ExecStart) GetUser() string

func (*ExecStart) GetWorkdir

func (x *ExecStart) GetWorkdir() string

func (*ExecStart) GetWorkspaceId

func (x *ExecStart) GetWorkspaceId() string

func (*ExecStart) ProtoMessage

func (*ExecStart) ProtoMessage()

func (*ExecStart) ProtoReflect

func (x *ExecStart) ProtoReflect() protoreflect.Message

func (*ExecStart) Reset

func (x *ExecStart) Reset()

func (*ExecStart) String

func (x *ExecStart) String() string

type FindRequest

type FindRequest struct {
	WorkspaceId string `protobuf:"bytes,1,opt,name=workspace_id,json=workspaceId,proto3" json:"workspace_id,omitempty"`
	// contains filtered or unexported fields
}

func (*FindRequest) Descriptor deprecated

func (*FindRequest) Descriptor() ([]byte, []int)

Deprecated: Use FindRequest.ProtoReflect.Descriptor instead.

func (*FindRequest) GetWorkspaceId

func (x *FindRequest) GetWorkspaceId() string

func (*FindRequest) ProtoMessage

func (*FindRequest) ProtoMessage()

func (*FindRequest) ProtoReflect

func (x *FindRequest) ProtoReflect() protoreflect.Message

func (*FindRequest) Reset

func (x *FindRequest) Reset()

func (*FindRequest) String

func (x *FindRequest) String() string

type FindResponse

type FindResponse struct {
	Found     bool              `protobuf:"varint,1,opt,name=found,proto3" json:"found,omitempty"`
	Container *ContainerDetails `protobuf:"bytes,2,opt,name=container,proto3" json:"container,omitempty"`
	// contains filtered or unexported fields
}

func (*FindResponse) Descriptor deprecated

func (*FindResponse) Descriptor() ([]byte, []int)

Deprecated: Use FindResponse.ProtoReflect.Descriptor instead.

func (*FindResponse) GetContainer

func (x *FindResponse) GetContainer() *ContainerDetails

func (*FindResponse) GetFound

func (x *FindResponse) GetFound() bool

func (*FindResponse) ProtoMessage

func (*FindResponse) ProtoMessage()

func (*FindResponse) ProtoReflect

func (x *FindResponse) ProtoReflect() protoreflect.Message

func (*FindResponse) Reset

func (x *FindResponse) Reset()

func (*FindResponse) String

func (x *FindResponse) String() string

type GpuRequirement

type GpuRequirement struct {
	Value GpuRequirementValue `protobuf:"varint,1,opt,name=value,proto3,enum=devsy.runtime.v1.GpuRequirementValue" json:"value,omitempty"`
	// contains filtered or unexported fields
}

func (*GpuRequirement) Descriptor deprecated

func (*GpuRequirement) Descriptor() ([]byte, []int)

Deprecated: Use GpuRequirement.ProtoReflect.Descriptor instead.

func (*GpuRequirement) GetValue

func (x *GpuRequirement) GetValue() GpuRequirementValue

func (*GpuRequirement) ProtoMessage

func (*GpuRequirement) ProtoMessage()

func (*GpuRequirement) ProtoReflect

func (x *GpuRequirement) ProtoReflect() protoreflect.Message

func (*GpuRequirement) Reset

func (x *GpuRequirement) Reset()

func (*GpuRequirement) String

func (x *GpuRequirement) String() string

type GpuRequirementValue

type GpuRequirementValue int32
const (
	GpuRequirementValue_GPU_UNSPECIFIED GpuRequirementValue = 0
	GpuRequirementValue_GPU_FALSE       GpuRequirementValue = 1
	GpuRequirementValue_GPU_OPTIONAL    GpuRequirementValue = 2
	GpuRequirementValue_GPU_REQUIRED    GpuRequirementValue = 3
)

func (GpuRequirementValue) Descriptor

func (GpuRequirementValue) Enum

func (GpuRequirementValue) EnumDescriptor deprecated

func (GpuRequirementValue) EnumDescriptor() ([]byte, []int)

Deprecated: Use GpuRequirementValue.Descriptor instead.

func (GpuRequirementValue) Number

func (GpuRequirementValue) String

func (x GpuRequirementValue) String() string

func (GpuRequirementValue) Type

type HostRequirements

type HostRequirements struct {
	Cpus         int32           `protobuf:"varint,1,opt,name=cpus,proto3" json:"cpus,omitempty"`
	MemoryBytes  uint64          `protobuf:"varint,2,opt,name=memory_bytes,json=memoryBytes,proto3" json:"memory_bytes,omitempty"`
	StorageBytes uint64          `protobuf:"varint,3,opt,name=storage_bytes,json=storageBytes,proto3" json:"storage_bytes,omitempty"`
	Gpu          *GpuRequirement `protobuf:"bytes,4,opt,name=gpu,proto3" json:"gpu,omitempty"`
	// contains filtered or unexported fields
}

func (*HostRequirements) Descriptor deprecated

func (*HostRequirements) Descriptor() ([]byte, []int)

Deprecated: Use HostRequirements.ProtoReflect.Descriptor instead.

func (*HostRequirements) GetCpus

func (x *HostRequirements) GetCpus() int32

func (*HostRequirements) GetGpu

func (x *HostRequirements) GetGpu() *GpuRequirement

func (*HostRequirements) GetMemoryBytes

func (x *HostRequirements) GetMemoryBytes() uint64

func (*HostRequirements) GetStorageBytes

func (x *HostRequirements) GetStorageBytes() uint64

func (*HostRequirements) ProtoMessage

func (*HostRequirements) ProtoMessage()

func (*HostRequirements) ProtoReflect

func (x *HostRequirements) ProtoReflect() protoreflect.Message

func (*HostRequirements) Reset

func (x *HostRequirements) Reset()

func (*HostRequirements) String

func (x *HostRequirements) String() string

type InfoRequest

type InfoRequest struct {
	// contains filtered or unexported fields
}

func (*InfoRequest) Descriptor deprecated

func (*InfoRequest) Descriptor() ([]byte, []int)

Deprecated: Use InfoRequest.ProtoReflect.Descriptor instead.

func (*InfoRequest) ProtoMessage

func (*InfoRequest) ProtoMessage()

func (*InfoRequest) ProtoReflect

func (x *InfoRequest) ProtoReflect() protoreflect.Message

func (*InfoRequest) Reset

func (x *InfoRequest) Reset()

func (*InfoRequest) String

func (x *InfoRequest) String() string

type InfoResponse

type InfoResponse struct {
	ApiMajor       uint32        `protobuf:"varint,1,opt,name=api_major,json=apiMajor,proto3" json:"api_major,omitempty"`
	ApiMinor       uint32        `protobuf:"varint,2,opt,name=api_minor,json=apiMinor,proto3" json:"api_minor,omitempty"`
	DriverName     string        `protobuf:"bytes,3,opt,name=driver_name,json=driverName,proto3" json:"driver_name,omitempty"`
	DriverVersion  string        `protobuf:"bytes,4,opt,name=driver_version,json=driverVersion,proto3" json:"driver_version,omitempty"`
	RuntimeName    string        `protobuf:"bytes,5,opt,name=runtime_name,json=runtimeName,proto3" json:"runtime_name,omitempty"`
	RuntimeVersion string        `protobuf:"bytes,6,opt,name=runtime_version,json=runtimeVersion,proto3" json:"runtime_version,omitempty"`
	Capabilities   *Capabilities `protobuf:"bytes,7,opt,name=capabilities,proto3" json:"capabilities,omitempty"`
	// contains filtered or unexported fields
}

func (*InfoResponse) Descriptor deprecated

func (*InfoResponse) Descriptor() ([]byte, []int)

Deprecated: Use InfoResponse.ProtoReflect.Descriptor instead.

func (*InfoResponse) GetApiMajor

func (x *InfoResponse) GetApiMajor() uint32

func (*InfoResponse) GetApiMinor

func (x *InfoResponse) GetApiMinor() uint32

func (*InfoResponse) GetCapabilities

func (x *InfoResponse) GetCapabilities() *Capabilities

func (*InfoResponse) GetDriverName

func (x *InfoResponse) GetDriverName() string

func (*InfoResponse) GetDriverVersion

func (x *InfoResponse) GetDriverVersion() string

func (*InfoResponse) GetRuntimeName

func (x *InfoResponse) GetRuntimeName() string

func (*InfoResponse) GetRuntimeVersion

func (x *InfoResponse) GetRuntimeVersion() string

func (*InfoResponse) ProtoMessage

func (*InfoResponse) ProtoMessage()

func (*InfoResponse) ProtoReflect

func (x *InfoResponse) ProtoReflect() protoreflect.Message

func (*InfoResponse) Reset

func (x *InfoResponse) Reset()

func (*InfoResponse) String

func (x *InfoResponse) String() string

type LogsRequest

type LogsRequest struct {
	WorkspaceId string `protobuf:"bytes,1,opt,name=workspace_id,json=workspaceId,proto3" json:"workspace_id,omitempty"`
	// contains filtered or unexported fields
}

func (*LogsRequest) Descriptor deprecated

func (*LogsRequest) Descriptor() ([]byte, []int)

Deprecated: Use LogsRequest.ProtoReflect.Descriptor instead.

func (*LogsRequest) GetWorkspaceId

func (x *LogsRequest) GetWorkspaceId() string

func (*LogsRequest) ProtoMessage

func (*LogsRequest) ProtoMessage()

func (*LogsRequest) ProtoReflect

func (x *LogsRequest) ProtoReflect() protoreflect.Message

func (*LogsRequest) Reset

func (x *LogsRequest) Reset()

func (*LogsRequest) String

func (x *LogsRequest) String() string

type Mount

type Mount struct {
	Type     MountType `protobuf:"varint,1,opt,name=type,proto3,enum=devsy.runtime.v1.MountType" json:"type,omitempty"`
	Source   string    `protobuf:"bytes,2,opt,name=source,proto3" json:"source,omitempty"`
	Target   string    `protobuf:"bytes,3,opt,name=target,proto3" json:"target,omitempty"`
	ReadOnly bool      `protobuf:"varint,4,opt,name=read_only,json=readOnly,proto3" json:"read_only,omitempty"`
	Options  []string  `protobuf:"bytes,5,rep,name=options,proto3" json:"options,omitempty"`
	// contains filtered or unexported fields
}

func (*Mount) Descriptor deprecated

func (*Mount) Descriptor() ([]byte, []int)

Deprecated: Use Mount.ProtoReflect.Descriptor instead.

func (*Mount) GetOptions

func (x *Mount) GetOptions() []string

func (*Mount) GetReadOnly

func (x *Mount) GetReadOnly() bool

func (*Mount) GetSource

func (x *Mount) GetSource() string

func (*Mount) GetTarget

func (x *Mount) GetTarget() string

func (*Mount) GetType

func (x *Mount) GetType() MountType

func (*Mount) ProtoMessage

func (*Mount) ProtoMessage()

func (*Mount) ProtoReflect

func (x *Mount) ProtoReflect() protoreflect.Message

func (*Mount) Reset

func (x *Mount) Reset()

func (*Mount) String

func (x *Mount) String() string

type MountType

type MountType int32
const (
	MountType_MOUNT_TYPE_UNSPECIFIED MountType = 0
	MountType_MOUNT_TYPE_BIND        MountType = 1
	MountType_MOUNT_TYPE_VOLUME      MountType = 2
	MountType_MOUNT_TYPE_TMPFS       MountType = 3
)

func (MountType) Descriptor

func (MountType) Descriptor() protoreflect.EnumDescriptor

func (MountType) Enum

func (x MountType) Enum() *MountType

func (MountType) EnumDescriptor deprecated

func (MountType) EnumDescriptor() ([]byte, []int)

Deprecated: Use MountType.Descriptor instead.

func (MountType) Number

func (x MountType) Number() protoreflect.EnumNumber

func (MountType) String

func (x MountType) String() string

func (MountType) Type

type OutputChunk

type OutputChunk struct {
	Data []byte `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

func (*OutputChunk) Descriptor deprecated

func (*OutputChunk) Descriptor() ([]byte, []int)

Deprecated: Use OutputChunk.ProtoReflect.Descriptor instead.

func (*OutputChunk) GetData

func (x *OutputChunk) GetData() []byte

func (*OutputChunk) ProtoMessage

func (*OutputChunk) ProtoMessage()

func (*OutputChunk) ProtoReflect

func (x *OutputChunk) ProtoReflect() protoreflect.Message

func (*OutputChunk) Reset

func (x *OutputChunk) Reset()

func (*OutputChunk) String

func (x *OutputChunk) String() string

type PreflightRequest

type PreflightRequest struct {
	DisableAutoStart bool `protobuf:"varint,1,opt,name=disable_auto_start,json=disableAutoStart,proto3" json:"disable_auto_start,omitempty"`
	// contains filtered or unexported fields
}

func (*PreflightRequest) Descriptor deprecated

func (*PreflightRequest) Descriptor() ([]byte, []int)

Deprecated: Use PreflightRequest.ProtoReflect.Descriptor instead.

func (*PreflightRequest) GetDisableAutoStart

func (x *PreflightRequest) GetDisableAutoStart() bool

func (*PreflightRequest) ProtoMessage

func (*PreflightRequest) ProtoMessage()

func (*PreflightRequest) ProtoReflect

func (x *PreflightRequest) ProtoReflect() protoreflect.Message

func (*PreflightRequest) Reset

func (x *PreflightRequest) Reset()

func (*PreflightRequest) String

func (x *PreflightRequest) String() string

type PreflightResponse

type PreflightResponse struct {
	// contains filtered or unexported fields
}

func (*PreflightResponse) Descriptor deprecated

func (*PreflightResponse) Descriptor() ([]byte, []int)

Deprecated: Use PreflightResponse.ProtoReflect.Descriptor instead.

func (*PreflightResponse) ProtoMessage

func (*PreflightResponse) ProtoMessage()

func (*PreflightResponse) ProtoReflect

func (x *PreflightResponse) ProtoReflect() protoreflect.Message

func (*PreflightResponse) Reset

func (x *PreflightResponse) Reset()

func (*PreflightResponse) String

func (x *PreflightResponse) String() string

type ProvisioningPreflightRequest

type ProvisioningPreflightRequest struct {
	// contains filtered or unexported fields
}

func (*ProvisioningPreflightRequest) Descriptor deprecated

func (*ProvisioningPreflightRequest) Descriptor() ([]byte, []int)

Deprecated: Use ProvisioningPreflightRequest.ProtoReflect.Descriptor instead.

func (*ProvisioningPreflightRequest) ProtoMessage

func (*ProvisioningPreflightRequest) ProtoMessage()

func (*ProvisioningPreflightRequest) ProtoReflect

func (*ProvisioningPreflightRequest) Reset

func (x *ProvisioningPreflightRequest) Reset()

func (*ProvisioningPreflightRequest) String

type ProvisioningPreflightResponse

type ProvisioningPreflightResponse struct {
	// contains filtered or unexported fields
}

func (*ProvisioningPreflightResponse) Descriptor deprecated

func (*ProvisioningPreflightResponse) Descriptor() ([]byte, []int)

Deprecated: Use ProvisioningPreflightResponse.ProtoReflect.Descriptor instead.

func (*ProvisioningPreflightResponse) ProtoMessage

func (*ProvisioningPreflightResponse) ProtoMessage()

func (*ProvisioningPreflightResponse) ProtoReflect

func (*ProvisioningPreflightResponse) Reset

func (x *ProvisioningPreflightResponse) Reset()

func (*ProvisioningPreflightResponse) String

type RecreateMode

type RecreateMode int32
const (
	RecreateMode_RECREATE_MODE_UNSPECIFIED RecreateMode = 0
	RecreateMode_RECREATE_MODE_DELETE      RecreateMode = 1
	RecreateMode_RECREATE_MODE_STOP        RecreateMode = 2
)

func (RecreateMode) Descriptor

func (RecreateMode) Enum

func (x RecreateMode) Enum() *RecreateMode

func (RecreateMode) EnumDescriptor deprecated

func (RecreateMode) EnumDescriptor() ([]byte, []int)

Deprecated: Use RecreateMode.Descriptor instead.

func (RecreateMode) Number

func (RecreateMode) String

func (x RecreateMode) String() string

func (RecreateMode) Type

type RunImageRequest

type RunImageRequest struct {
	WorkspaceId       string            `protobuf:"bytes,1,opt,name=workspace_id,json=workspaceId,proto3" json:"workspace_id,omitempty"`
	Image             string            `protobuf:"bytes,2,opt,name=image,proto3" json:"image,omitempty"`
	ImageBuiltLocally bool              `protobuf:"varint,3,opt,name=image_built_locally,json=imageBuiltLocally,proto3" json:"image_built_locally,omitempty"`
	User              string            `protobuf:"bytes,4,opt,name=user,proto3" json:"user,omitempty"`
	Entrypoint        string            `protobuf:"bytes,5,opt,name=entrypoint,proto3" json:"entrypoint,omitempty"`
	Args              []string          `protobuf:"bytes,6,rep,name=args,proto3" json:"args,omitempty"`
	Environment       map[string]string `` /* 149-byte string literal not displayed */
	Labels            []string          `protobuf:"bytes,8,rep,name=labels,proto3" json:"labels,omitempty"`
	CapAdd            []string          `protobuf:"bytes,9,rep,name=cap_add,json=capAdd,proto3" json:"cap_add,omitempty"`
	SecurityOpt       []string          `protobuf:"bytes,10,rep,name=security_opt,json=securityOpt,proto3" json:"security_opt,omitempty"`
	Privileged        *bool             `protobuf:"varint,11,opt,name=privileged,proto3,oneof" json:"privileged,omitempty"`
	Init              *bool             `protobuf:"varint,12,opt,name=init,proto3,oneof" json:"init,omitempty"`
	WorkspaceMount    *Mount            `protobuf:"bytes,13,opt,name=workspace_mount,json=workspaceMount,proto3" json:"workspace_mount,omitempty"`
	Mounts            []*Mount          `protobuf:"bytes,14,rep,name=mounts,proto3" json:"mounts,omitempty"`
	Userns            string            `protobuf:"bytes,15,opt,name=userns,proto3" json:"userns,omitempty"`
	UidMap            []string          `protobuf:"bytes,16,rep,name=uid_map,json=uidMap,proto3" json:"uid_map,omitempty"`
	GidMap            []string          `protobuf:"bytes,17,rep,name=gid_map,json=gidMap,proto3" json:"gid_map,omitempty"`
	Platform          string            `protobuf:"bytes,18,opt,name=platform,proto3" json:"platform,omitempty"`
	HostRequirements  *HostRequirements `protobuf:"bytes,19,opt,name=host_requirements,json=hostRequirements,proto3" json:"host_requirements,omitempty"`
	// Developer identity for workspace ownership, distinct from the container user.
	// When empty, use user if set, otherwise root.
	RemoteUser string `protobuf:"bytes,20,opt,name=remote_user,json=remoteUser,proto3" json:"remote_user,omitempty"`
	// The host will provision the developer environment after starting this image.
	// Runtimes must not assume the final developer identity exists in the image.
	Dockerless bool `protobuf:"varint,21,opt,name=dockerless,proto3" json:"dockerless,omitempty"`
	// contains filtered or unexported fields
}

func (*RunImageRequest) Descriptor deprecated

func (*RunImageRequest) Descriptor() ([]byte, []int)

Deprecated: Use RunImageRequest.ProtoReflect.Descriptor instead.

func (*RunImageRequest) GetArgs

func (x *RunImageRequest) GetArgs() []string

func (*RunImageRequest) GetCapAdd

func (x *RunImageRequest) GetCapAdd() []string

func (*RunImageRequest) GetDockerless added in v1.4.0

func (x *RunImageRequest) GetDockerless() bool

func (*RunImageRequest) GetEntrypoint

func (x *RunImageRequest) GetEntrypoint() string

func (*RunImageRequest) GetEnvironment

func (x *RunImageRequest) GetEnvironment() map[string]string

func (*RunImageRequest) GetGidMap

func (x *RunImageRequest) GetGidMap() []string

func (*RunImageRequest) GetHostRequirements

func (x *RunImageRequest) GetHostRequirements() *HostRequirements

func (*RunImageRequest) GetImage

func (x *RunImageRequest) GetImage() string

func (*RunImageRequest) GetImageBuiltLocally

func (x *RunImageRequest) GetImageBuiltLocally() bool

func (*RunImageRequest) GetInit

func (x *RunImageRequest) GetInit() bool

func (*RunImageRequest) GetLabels

func (x *RunImageRequest) GetLabels() []string

func (*RunImageRequest) GetMounts

func (x *RunImageRequest) GetMounts() []*Mount

func (*RunImageRequest) GetPlatform

func (x *RunImageRequest) GetPlatform() string

func (*RunImageRequest) GetPrivileged

func (x *RunImageRequest) GetPrivileged() bool

func (*RunImageRequest) GetRemoteUser added in v1.4.0

func (x *RunImageRequest) GetRemoteUser() string

func (*RunImageRequest) GetSecurityOpt

func (x *RunImageRequest) GetSecurityOpt() []string

func (*RunImageRequest) GetUidMap

func (x *RunImageRequest) GetUidMap() []string

func (*RunImageRequest) GetUser

func (x *RunImageRequest) GetUser() string

func (*RunImageRequest) GetUserns

func (x *RunImageRequest) GetUserns() string

func (*RunImageRequest) GetWorkspaceId

func (x *RunImageRequest) GetWorkspaceId() string

func (*RunImageRequest) GetWorkspaceMount

func (x *RunImageRequest) GetWorkspaceMount() *Mount

func (*RunImageRequest) ProtoMessage

func (*RunImageRequest) ProtoMessage()

func (*RunImageRequest) ProtoReflect

func (x *RunImageRequest) ProtoReflect() protoreflect.Message

func (*RunImageRequest) Reset

func (x *RunImageRequest) Reset()

func (*RunImageRequest) String

func (x *RunImageRequest) String() string

type RunImageResponse

type RunImageResponse struct {
	// contains filtered or unexported fields
}

func (*RunImageResponse) Descriptor deprecated

func (*RunImageResponse) Descriptor() ([]byte, []int)

Deprecated: Use RunImageResponse.ProtoReflect.Descriptor instead.

func (*RunImageResponse) ProtoMessage

func (*RunImageResponse) ProtoMessage()

func (*RunImageResponse) ProtoReflect

func (x *RunImageResponse) ProtoReflect() protoreflect.Message

func (*RunImageResponse) Reset

func (x *RunImageResponse) Reset()

func (*RunImageResponse) String

func (x *RunImageResponse) String() string

type RuntimeDriverClient

RuntimeDriverClient is the client API for RuntimeDriver service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type RuntimeDriverServer

RuntimeDriverServer is the server API for RuntimeDriver service. All implementations must embed UnimplementedRuntimeDriverServer for forward compatibility.

type RuntimeDriver_ExecClient

type RuntimeDriver_ExecClient = grpc.BidiStreamingClient[ExecClientMessage, ExecServerMessage]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type RuntimeDriver_ExecServer

type RuntimeDriver_ExecServer = grpc.BidiStreamingServer[ExecClientMessage, ExecServerMessage]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type RuntimeDriver_LogsClient

type RuntimeDriver_LogsClient = grpc.ServerStreamingClient[OutputChunk]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type RuntimeDriver_LogsServer

type RuntimeDriver_LogsServer = grpc.ServerStreamingServer[OutputChunk]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type RuntimeError

type RuntimeError struct {
	Code           RuntimeErrorCode  `protobuf:"varint,1,opt,name=code,proto3,enum=devsy.runtime.v1.RuntimeErrorCode" json:"code,omitempty"`
	Message        string            `protobuf:"bytes,2,opt,name=message,proto3" json:"message,omitempty"`
	RuntimeMessage string            `protobuf:"bytes,3,opt,name=runtime_message,json=runtimeMessage,proto3" json:"runtime_message,omitempty"`
	Retryable      bool              `protobuf:"varint,4,opt,name=retryable,proto3" json:"retryable,omitempty"`
	Details        map[string]string `` /* 141-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*RuntimeError) Descriptor deprecated

func (*RuntimeError) Descriptor() ([]byte, []int)

Deprecated: Use RuntimeError.ProtoReflect.Descriptor instead.

func (*RuntimeError) GetCode

func (x *RuntimeError) GetCode() RuntimeErrorCode

func (*RuntimeError) GetDetails

func (x *RuntimeError) GetDetails() map[string]string

func (*RuntimeError) GetMessage

func (x *RuntimeError) GetMessage() string

func (*RuntimeError) GetRetryable

func (x *RuntimeError) GetRetryable() bool

func (*RuntimeError) GetRuntimeMessage

func (x *RuntimeError) GetRuntimeMessage() string

func (*RuntimeError) ProtoMessage

func (*RuntimeError) ProtoMessage()

func (*RuntimeError) ProtoReflect

func (x *RuntimeError) ProtoReflect() protoreflect.Message

func (*RuntimeError) Reset

func (x *RuntimeError) Reset()

func (*RuntimeError) String

func (x *RuntimeError) String() string

type RuntimeErrorCode

type RuntimeErrorCode int32
const (
	RuntimeErrorCode_RUNTIME_ERROR_CODE_UNKNOWN              RuntimeErrorCode = 0
	RuntimeErrorCode_RUNTIME_ERROR_CODE_NOT_FOUND            RuntimeErrorCode = 1
	RuntimeErrorCode_RUNTIME_ERROR_CODE_ALREADY_EXISTS       RuntimeErrorCode = 2
	RuntimeErrorCode_RUNTIME_ERROR_CODE_INVALID_ARGUMENT     RuntimeErrorCode = 3
	RuntimeErrorCode_RUNTIME_ERROR_CODE_UNSUPPORTED          RuntimeErrorCode = 4
	RuntimeErrorCode_RUNTIME_ERROR_CODE_UNAVAILABLE          RuntimeErrorCode = 5
	RuntimeErrorCode_RUNTIME_ERROR_CODE_FAILED_PRECONDITION  RuntimeErrorCode = 6
	RuntimeErrorCode_RUNTIME_ERROR_CODE_PERMISSION_DENIED    RuntimeErrorCode = 7
	RuntimeErrorCode_RUNTIME_ERROR_CODE_TIMEOUT              RuntimeErrorCode = 8
	RuntimeErrorCode_RUNTIME_ERROR_CODE_CANCELLED            RuntimeErrorCode = 9
	RuntimeErrorCode_RUNTIME_ERROR_CODE_RUNTIME_FAILURE      RuntimeErrorCode = 10
	RuntimeErrorCode_RUNTIME_ERROR_CODE_INCOMPATIBLE_VERSION RuntimeErrorCode = 11
)

func (RuntimeErrorCode) Descriptor

func (RuntimeErrorCode) Enum

func (RuntimeErrorCode) EnumDescriptor deprecated

func (RuntimeErrorCode) EnumDescriptor() ([]byte, []int)

Deprecated: Use RuntimeErrorCode.Descriptor instead.

func (RuntimeErrorCode) Number

func (RuntimeErrorCode) String

func (x RuntimeErrorCode) String() string

func (RuntimeErrorCode) Type

type StartRequest

type StartRequest struct {
	WorkspaceId string `protobuf:"bytes,1,opt,name=workspace_id,json=workspaceId,proto3" json:"workspace_id,omitempty"`
	// contains filtered or unexported fields
}

func (*StartRequest) Descriptor deprecated

func (*StartRequest) Descriptor() ([]byte, []int)

Deprecated: Use StartRequest.ProtoReflect.Descriptor instead.

func (*StartRequest) GetWorkspaceId

func (x *StartRequest) GetWorkspaceId() string

func (*StartRequest) ProtoMessage

func (*StartRequest) ProtoMessage()

func (*StartRequest) ProtoReflect

func (x *StartRequest) ProtoReflect() protoreflect.Message

func (*StartRequest) Reset

func (x *StartRequest) Reset()

func (*StartRequest) String

func (x *StartRequest) String() string

type StartResponse

type StartResponse struct {
	// contains filtered or unexported fields
}

func (*StartResponse) Descriptor deprecated

func (*StartResponse) Descriptor() ([]byte, []int)

Deprecated: Use StartResponse.ProtoReflect.Descriptor instead.

func (*StartResponse) ProtoMessage

func (*StartResponse) ProtoMessage()

func (*StartResponse) ProtoReflect

func (x *StartResponse) ProtoReflect() protoreflect.Message

func (*StartResponse) Reset

func (x *StartResponse) Reset()

func (*StartResponse) String

func (x *StartResponse) String() string

type StopRequest

type StopRequest struct {
	WorkspaceId string `protobuf:"bytes,1,opt,name=workspace_id,json=workspaceId,proto3" json:"workspace_id,omitempty"`
	// contains filtered or unexported fields
}

func (*StopRequest) Descriptor deprecated

func (*StopRequest) Descriptor() ([]byte, []int)

Deprecated: Use StopRequest.ProtoReflect.Descriptor instead.

func (*StopRequest) GetWorkspaceId

func (x *StopRequest) GetWorkspaceId() string

func (*StopRequest) ProtoMessage

func (*StopRequest) ProtoMessage()

func (*StopRequest) ProtoReflect

func (x *StopRequest) ProtoReflect() protoreflect.Message

func (*StopRequest) Reset

func (x *StopRequest) Reset()

func (*StopRequest) String

func (x *StopRequest) String() string

type StopResponse

type StopResponse struct {
	// contains filtered or unexported fields
}

func (*StopResponse) Descriptor deprecated

func (*StopResponse) Descriptor() ([]byte, []int)

Deprecated: Use StopResponse.ProtoReflect.Descriptor instead.

func (*StopResponse) ProtoMessage

func (*StopResponse) ProtoMessage()

func (*StopResponse) ProtoReflect

func (x *StopResponse) ProtoReflect() protoreflect.Message

func (*StopResponse) Reset

func (x *StopResponse) Reset()

func (*StopResponse) String

func (x *StopResponse) String() string

type TargetArchitectureRequest

type TargetArchitectureRequest struct {
	WorkspaceId string `protobuf:"bytes,1,opt,name=workspace_id,json=workspaceId,proto3" json:"workspace_id,omitempty"`
	// contains filtered or unexported fields
}

func (*TargetArchitectureRequest) Descriptor deprecated

func (*TargetArchitectureRequest) Descriptor() ([]byte, []int)

Deprecated: Use TargetArchitectureRequest.ProtoReflect.Descriptor instead.

func (*TargetArchitectureRequest) GetWorkspaceId

func (x *TargetArchitectureRequest) GetWorkspaceId() string

func (*TargetArchitectureRequest) ProtoMessage

func (*TargetArchitectureRequest) ProtoMessage()

func (*TargetArchitectureRequest) ProtoReflect

func (*TargetArchitectureRequest) Reset

func (x *TargetArchitectureRequest) Reset()

func (*TargetArchitectureRequest) String

func (x *TargetArchitectureRequest) String() string

type TargetArchitectureResponse

type TargetArchitectureResponse struct {
	Architecture string `protobuf:"bytes,1,opt,name=architecture,proto3" json:"architecture,omitempty"`
	// contains filtered or unexported fields
}

func (*TargetArchitectureResponse) Descriptor deprecated

func (*TargetArchitectureResponse) Descriptor() ([]byte, []int)

Deprecated: Use TargetArchitectureResponse.ProtoReflect.Descriptor instead.

func (*TargetArchitectureResponse) GetArchitecture

func (x *TargetArchitectureResponse) GetArchitecture() string

func (*TargetArchitectureResponse) ProtoMessage

func (*TargetArchitectureResponse) ProtoMessage()

func (*TargetArchitectureResponse) ProtoReflect

func (*TargetArchitectureResponse) Reset

func (x *TargetArchitectureResponse) Reset()

func (*TargetArchitectureResponse) String

func (x *TargetArchitectureResponse) String() string

type UnimplementedRuntimeDriverServer

type UnimplementedRuntimeDriverServer struct{}

UnimplementedRuntimeDriverServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedRuntimeDriverServer) Delete

func (UnimplementedRuntimeDriverServer) Find

func (UnimplementedRuntimeDriverServer) Info

func (UnimplementedRuntimeDriverServer) Logs

func (UnimplementedRuntimeDriverServer) Preflight

func (UnimplementedRuntimeDriverServer) RunImage

func (UnimplementedRuntimeDriverServer) Start

func (UnimplementedRuntimeDriverServer) Stop

func (UnimplementedRuntimeDriverServer) TargetArchitecture

type UnsafeRuntimeDriverServer

type UnsafeRuntimeDriverServer interface {
	// contains filtered or unexported methods
}

UnsafeRuntimeDriverServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to RuntimeDriverServer will result in compilation errors.

Jump to